Crate ample

Crate ample 

Re-exports

pub use string::String;
pub use result::Error;
pub use result::Ok;
pub use result::Result;

Modules

list
macros
node
result
string
traits

Macros

chain_latter
enum
enum_flag
A macro that defines an error type and error handling for syscalls.
enum_labeled
A macro that defines an error type and error handling for syscalls.
enum_labeled_typed
A macro that defines an error type and error handling for syscalls.
enum_opted
enum_typed
expressions_lowerbound
expressions_upperbound
generic_struct
impl_string_allocable
make_default_or_given
result
struct
struct_tuple
trait_bytes_naturalize
trait_bytes_place
trait_implement_bytes
trait_implement_bytes_option
trait_implement_bytes_pointer
trait_implement_bytes_slice
trait_implement_from
trait_implement_partial_eq
trait_implement_primitive
trait_implement_primitive_bool_bytes
trait_implement_primitive_char_bytes
trait_implement_primitive_numeric_bytes
trait_implement_primitive_phantom_bytes
trait_implement_primitive_unit_bytes
trait_implement_primitives
trait_place_allocatable
trait_primitive_place
traits_impl_blanket_bytes
traits_implement_bytes_tuple

Structs

Origin